@@ -5,7 +5,7 @@ easy_functions是一个简单但实用的Python模块，可以通过import文件
 本模块使用MIT协议
 """
 #更新状态:活跃
-cmdlist = ['bigfont','literally','wait','cls','title','find_file','start','call','Vbs','color','mode','shield','choice','Code','mkdir','copy','help','helpcmd','version','log'] #命令列表，以大写字母开头的为类(class)
+cmdlist = ['bigfont','literally','wait','cls','title','find_file','start','call','Vbs','color','mode','shield','choice','Code','mkdir','copy','pause','help','helpcmd','version','log'] #命令列表，以大写字母开头的为类(class)
 __all__ = cmdlist
 c = 0
 d = 0
@@ -13,7 +13,7 @@ for i in cmdlist:
     if i.istitle():
         c += 1
 d = len(cmdlist) - c
-__version__ = str(c) + '.' + str(d) + '.' + '63' #easy_functions版本号
+__version__ = str(c) + '.' + str(d) + '.' + '65' #easy_functions版本号
 __author__ = 'Jerry\n我的QQ号：2711893794' #作者
 class FunctionSyntaxError(Exception):
     def __init__(self, *error):
@@ -139,7 +139,9 @@ def literally(text, wait=0.1): #逐字显示
     try:
         wait + 1
     except TypeError as e:
-        raise FunctionSyntaxError('你输入的值%s不符合运行要求，请输入数字'%wait) from e
+        raise FunctionSyntaxError(
+            '你输入的值%s不符合运行要求，请输入数字'%wait
+        ) from e
     import sys, time
     sys.stdout.write("\n " + " " * 60 + "\r")
     sys.stdout.flush()
@@ -153,7 +155,9 @@ def wait(wait=1): #等待功能
     try:
         time.sleep(wait)
     except TypeError as e:
-        raise FunctionSyntaxError('你输入的值%s不符合运行要求，请输入数字'%wait) from e
+        raise FunctionSyntaxError(
+            '你输入的值%s不符合运行要求，请输入数字'%wait
+        ) from e
     return
 def cls(): #清除屏幕功能
     import os
@@ -262,10 +266,14 @@ def color( color ): #更改颜色
         try:
             coloroutrange = color[1]
         except IndexError as e:
-            raise FunctionSyntaxError('这不是一个完整的颜色编码') from e
+            raise FunctionSyntaxError(
+                '%s不是一个完整的颜色编码'%color
+            ) from e
         else:
             if color[0].isupper() or color[1].isupper():
-                raise FunctionSyntaxError('颜色编码必须小写')
+                raise FunctionSyntaxError(
+                    '%s中含有大写字母，颜色编码必须小写'%color
+                )
             elif color[0] in colorfontlist and color[1] in colorbacklist:
                 os.system('color ' + color)
             elif color[0] in colorbacklist and color[1] in colorfontlist:
@@ -275,9 +283,13 @@ def color( color ): #更改颜色
             elif color[0] in colorfontlist and color[1] in colorfontlist:
                 os.system('color ' + color)
             else:
-                raise FunctionSyntaxError('无效颜色编码') from e
+                raise FunctionSyntaxError(
+                    '无效颜色编码%s'%color
+                ) from e
     else:
-        raise FunctionSyntaxError('不支持2个以上的颜色编码')
+        raise FunctionSyntaxError(
+            '不支持2个以上的颜色编码%s'%color
+        )
     return
 def mode(cols, lines): #更改cmd外框大小
     import os
@@ -287,12 +299,16 @@ def mode(cols, lines): #更改cmd外框大小
         try:
             int(cols) + 1
         except ValueError as e:
-            raise FunctionSyntaxError('请不要输入除数字外的字母，符号等') from e
+            raise FunctionSyntaxError(
+                '请不要输入除数字外的字母，符号等'
+            ) from e
             return
         else:
             c = cols
     else:
-        raise FunctionSyntaxError('该功能需要输入字符串，而你输入了数字') from e
+        raise FunctionSyntaxError(
+            '该功能需要输入字符串，而你输入了数字'
+        ) from e
         return
     try:
         lines + 1
@@ -300,12 +316,16 @@ def mode(cols, lines): #更改cmd外框大小
         try:
             int(lines) + 1
         except ValueError as e:
-            raise FunctionSyntaxError('请不要输入除数字外的字母，符号等') from e
+            raise FunctionSyntaxError(
+                '请不要输入除数字外的字母，符号等'
+            ) from e
             return
         else:
             l = lines
     else:
-        raise FunctionSyntaxError('该功能需要输入字符串，而你输入了数字') from e
+        raise FunctionSyntaxError(
+            '该功能需要输入字符串，而你输入了数字'
+        ) from e
         return
     os.system('mode con cols=' + c + ' lines=' + l)
     return
@@ -314,7 +334,9 @@ def shield(words, WordsBlackList): #词语屏蔽
     try:
         WordsBlackList.append('test')
     except AttributeError as e:
-        raise FunctionSyntaxError('功能shield的词语黑名单需要传入列表') from e
+        raise FunctionSyntaxError(
+            '功能shield的词语黑名单需要传入列表'
+        ) from e
     else:
         WordsBlackList.pop()
         for i in WordsBlackList:
@@ -327,7 +349,9 @@ def choice(choose='YN', text='Y/N', default='False', timeout='10', *, hide=False
     choice = choice + ' /C '
     for i in range(len(text)):
         if text[i] == ' ':
-            raise FunctionSyntaxError('显示的文字中不能含有空格')
+            raise FunctionSyntaxError(
+                '显示的文字中不能含有空格'
+            )
     if hide is True: 
         choice = choice + choose + ' /N ' + ' /M ' + text
     else:
@@ -337,7 +361,9 @@ def choice(choose='YN', text='Y/N', default='False', timeout='10', *, hide=False
             choice = choice + ' /D ' + default
             choice = choice + ' /T ' + timeout
         elif default not in choose:
-            raise FunctionSyntaxError('按键默认值不在设置的按键中')
+            raise FunctionSyntaxError(
+                '按键默认值不在设置的按键中'
+            )
     return os.system(choice)
 class Code: #加密英文
     def __init__( self ):
@@ -360,9 +386,18 @@ class Code: #加密英文
 def mkdir( path ): #新建文件夹
     import os
     return os.system('mkdir ' + path)
-def copy(filein, fileout):
+def copy(filein, fileout): #文件复制功能
     import os
+    if not find_file(filein):
+        raise FileNotFoundError(
+            '没有名为%s的文件'%filein
+        )
     return os.system('copy ' + filein + ' ' + fileout + ' ' + '>nul')
+def pause(text='请按任意键继续...'): #文件删除功能
+    import os
+    print(text)
+    os.system('pause >nul')
+    return
 def log(): #更新日志
     print('')
     print('作者决定，从2021-3-21起开始记录本模块的更新')
@@ -412,7 +447,7 @@ def log(): #更新日志
     print('1.在功能choice中增加了一条检测语句，现在显示的文字中含有空格将会报错')
     print('')
     print('[2021-5-6] [1条更新]')
-    print('1.因为python官网的重名，本模块由pymod更名为SimpleFunctions')
+    print('1.因为PyPi官网的重名，本模块由pymod更名为SimpleFunctions')
     print('')
     print('[2021-5-7] [1条更新]')
     print('1.对start功能进行了微调')
@@ -439,10 +474,18 @@ def log(): #更新日志
     print('[2021-5-29] [1条更新]')
     print('1.在功能Vbs中添加了4条检测语句，使得标题和正文中的换行符和回车符被忽略')
     print('')
-    print('[2021-6-13] [3条更新]')
+    print('[2021-6-13] [4条更新]')
     print('1.对功能Vbs在helpcmd()中的解释进行了微调')
     print('2.对功能call在helpcmd()中的解释进行了微调')
     print('3.对功能color的bug进行了修复')
+    print('4.对所有的报错进行了优化')
+    print('')
+    print('[2021-6-18] [2条更新]')
+    print('1.在功能copy中增加了一条检测语句，使文件不存在时报错')
+    print('2.增加了pause功能，具体使用helpcmd()查看')
+    print('')
+    print('[2021-6-19] [1条更新]')
+    print('1.对功能color的报错进行了优化')
     print('')
     return
 def version(): #版本
@@ -591,6 +634,11 @@ def helpcmd( cmd ): #文件命令功能解释
         print('      你可以更改复制出来的文件的后缀名，但这只限于纯文本')
         print('      对于非纯文本的文件，例如docx，ppt等，因更改后缀而造成的文件损坏、编码缺失等问题，作者概不负责')
         return
+    if cmd == 'pause':
+        print('<',cmd,'>','暂停功能')
+        print("用法：文件名或<import...as...>命令别名.pause('显示的文字')")
+        print("这个命令和使用input('显示的文字')的区别是input()是pause()只需要按下键盘上的任意按键，而input()需要按下回车")
+        return
     if cmd == 'log':
         print('<',cmd,'>','更新日志查看功能')
         print('更新日志从2021-3-21开始记录')
